@@ -6,6 +6,8 @@
 import os
 import sys
 import logging
+import traceback
+
 import tornado.web
 import tornado.ioloop
 import tornado.httpserver
@@ -118,7 +120,7 @@ class WebServer:
         self.autoRegisterExtendHandler()
         if options.scheduler_config.get("enable", False):
             self.init_scheduler()
-        handlers = options.restful_handler+RouterMapping.instance()
+        handlers = options.restful_handler + RouterMapping.instance()
         self.app = tornado.web.Application(
             handlers,
             cookie_secret=options.cookie_secret,
@@ -129,51 +131,7 @@ class WebServer:
         self.server = tornado.httpserver.HTTPServer(self.app, max_buffer_size=500 * 1024 * 1024, xheaders=True)  # 500M
 
     def start(self, num_processes: Optional[int] = 1, max_restarts: int = None):
-        if options.eureka_config.get("enable"):
-            import py_eureka_client.eureka_client as eureka_client
-            eureka_instance_name = options.eureka_config.get("instance_name") if options.eureka_config.get(
-                "instance_name") else options.application_name
-            eureka_instance_ip = options.eureka_config.get("instance_ip") if options.eureka_config.get(
-                "instance_ip") else "127.0.0.1"
-            eureka_instance_port = options.eureka_config.get("instance_port") if options.eureka_config.get(
-                "instance_port") else options.port
-            eureka_client.init(eureka_server=options.eureka_config.get("eureka_server"),
-                               app_name=eureka_instance_name,
-                               instance_ip=eureka_instance_ip,
-                               instance_port=eureka_instance_port)
-        if options.nacos_config.get("enable"):
-            import nacos
-            nacos_service_name = options.nacos_config.get("service_name") if options.nacos_config.get(
-                "service_name") else options.application_name
-            nacos_namespace = options.nacos_config.get("namespace") if options.nacos_config.get(
-                "namespace") else "public"
-            nacos_instance_ip = options.nacos_config.get("instance_ip") if options.nacos_config.get(
-                "instance_ip") else "127.0.0.1"
-            nacos_instance_port = options.nacos_config.get("instance_port") if options.nacos_config.get(
-                "instance_port") else options.port
-            nacos_instance_weight = options.nacos_config.get("instance_weight") if options.nacos_config.get(
-                "instance_weight") else 1.0
-            nacos_instance_enable = options.nacos_config.get("instance_enable") if options.nacos_config.get(
-                "instance_enable") else True
-            nacos_instance_healthy = options.nacos_config.get("instance_healthy") if options.nacos_config.get(
-                "instance_healthy") else True
-            nacos_instance_ephemeral = options.nacos_config.get("instance_ephemeral") if options.nacos_config.get(
-                "instance_ephemeral") else False
-            nacos_instance_group_name = options.nacos_config.get("instance_group_name") if options.nacos_config.get(
-                "instance_group_name") else "DEFAULT_GROUP"
-            nacos_client = nacos.NacosClient(server_addresses=options.nacos_config.get("server_addresses"),
-                                             namespace=nacos_namespace,
-                                             endpoint=options.nacos_config.get("endpoint"),
-                                             ak=options.nacos_config.get("ak"), sk=options.nacos_config.get("sk"),
-                                             username=options.nacos_config.get("username"),
-                                             password=options.nacos_config.get("password"))
-            nacos_client.add_naming_instance(service_name=nacos_service_name, ip=nacos_instance_ip,
-                                             port=nacos_instance_port,
-                                             cluster_name=options.nacos_config.get("cluster_name"),
-                                             weight=nacos_instance_weight,
-                                             metadata=options.nacos_config.get("instance_metadata"),
-                                             enable=nacos_instance_enable, healthy=nacos_instance_healthy,
-                                             ephemeral=nacos_instance_ephemeral, group_name=nacos_instance_group_name)
+        self.service_register()
         self.server.listen(options.port)
         self.server.start(num_processes, max_restarts)
         logging.info(f"start server : {options.application_name}")
@@ -232,3 +190,57 @@ class WebServer:
                                              **options.scheduler_config.get("options", {}))
         options.scheduler.start()
         logging.info('[Scheduler Init]APScheduler has been started')
+
+    def service_register(self):
+        try:
+            if options.eureka_config.get("enable"):
+                import py_eureka_client.eureka_client as eureka_client
+                eureka_instance_name = options.eureka_config.get("instance_name") if options.eureka_config.get(
+                    "instance_name") else options.application_name
+                eureka_instance_ip = options.eureka_config.get("instance_ip") if options.eureka_config.get(
+                    "instance_ip") else "127.0.0.1"
+                eureka_instance_port = options.eureka_config.get("instance_port") if options.eureka_config.get(
+                    "instance_port") else options.port
+                eureka_client.init(eureka_server=options.eureka_config.get("eureka_server"),
+                                   app_name=eureka_instance_name,
+                                   instance_ip=eureka_instance_ip,
+                                   instance_port=eureka_instance_port)
+                logging.info(f'service={eureka_instance_name} register success')
+            if options.nacos_config.get("enable"):
+                import nacos
+                nacos_service_name = options.nacos_config.get("service_name") if options.nacos_config.get(
+                    "service_name") else options.application_name
+                nacos_namespace = options.nacos_config.get("namespace") if options.nacos_config.get(
+                    "namespace") else "public"
+                nacos_instance_ip = options.nacos_config.get("instance_ip") if options.nacos_config.get(
+                    "instance_ip") else "127.0.0.1"
+                nacos_instance_port = options.nacos_config.get("instance_port") if options.nacos_config.get(
+                    "instance_port") else options.port
+                nacos_instance_weight = options.nacos_config.get("instance_weight") if options.nacos_config.get(
+                    "instance_weight") else 1.0
+                nacos_instance_enable = options.nacos_config.get("instance_enable") if options.nacos_config.get(
+                    "instance_enable") else True
+                nacos_instance_healthy = options.nacos_config.get("instance_healthy") if options.nacos_config.get(
+                    "instance_healthy") else True
+                nacos_instance_ephemeral = options.nacos_config.get("instance_ephemeral") if options.nacos_config.get(
+                    "instance_ephemeral") else False
+                nacos_instance_group_name = options.nacos_config.get("instance_group_name") if options.nacos_config.get(
+                    "instance_group_name") else "DEFAULT_GROUP"
+                nacos_client = nacos.NacosClient(server_addresses=options.nacos_config.get("server_addresses"),
+                                                 namespace=nacos_namespace,
+                                                 endpoint=options.nacos_config.get("endpoint"),
+                                                 ak=options.nacos_config.get("ak"), sk=options.nacos_config.get("sk"),
+                                                 username=options.nacos_config.get("username"),
+                                                 password=options.nacos_config.get("password"))
+                nacos_client.add_naming_instance(service_name=nacos_service_name, ip=nacos_instance_ip,
+                                                 port=nacos_instance_port,
+                                                 cluster_name=options.nacos_config.get("cluster_name"),
+                                                 weight=nacos_instance_weight,
+                                                 metadata=options.nacos_config.get("instance_metadata"),
+                                                 enable=nacos_instance_enable, healthy=nacos_instance_healthy,
+                                                 ephemeral=nacos_instance_ephemeral, group_name=nacos_instance_group_name)
+                logging.info(f'service={nacos_service_name} register success')
+
+        except Exception as e:
+            logging.info(f'service register fail,e:{e.__str__()}')
+            traceback.print_exc()
